| Package | Description |
|---|---|
| io.vertx.core.net | |
| io.vertx.core.streams |
| Class and Description |
|---|
| DataObject
Declares a data object, such object must provide at least:
a constructor with no arguments
a constructor with
JsonObject
a copy constructor
When the data object is processed, a model of properties from the setter methods or adder methods. |
| Class and Description |
|---|
| VertxGen
Declares a Java interface type to be processed for creating API in various languages of polyglot Vert.x.
|
Copyright © 2016. All rights reserved.